pub struct AmendmentDecisionV1 {
pub schema_version: String,
pub amendment_decision_id: AmendmentDecisionId,
pub amendment_proposal_id: AmendmentProposalId,
pub disposition: AmendmentDisposition,
pub semantic_diff_id: Option<SemanticDiffId>,
pub archive_manifest_id: Option<ArchiveManifestId>,
pub historical_query_guarantee_id: Option<HistoricalQueryGuaranteeId>,
pub archive_consequence_summary: String,
pub unresolved_obligations: Vec<String>,
pub advisory_only: bool,
pub rollback_ready: bool,
pub decided_at: String,
}Fields
schema_version: Stringamendment_decision_id: AmendmentDecisionIdamendment_proposal_id: AmendmentProposalIddisposition: AmendmentDispositionsemantic_diff_id: Option<SemanticDiffId>archive_manifest_id: Option<ArchiveManifestId>historical_query_guarantee_id: Option<HistoricalQueryGuaranteeId>archive_consequence_summary: Stringunresolved_obligations: Vec<String>advisory_only: boolrollback_ready: booldecided_at: StringTrait Implementations
Sourceimpl Clone for AmendmentDecisionV1
impl Clone for AmendmentDecisionV1
Sourcefn clone(&self) -> AmendmentDecisionV1
fn clone(&self) -> AmendmentDecisionV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AmendmentDecisionV1
impl Debug for AmendmentDecisionV1
Sourceimpl<'de> Deserialize<'de> for AmendmentDecisionV1
impl<'de> Deserialize<'de> for AmendmentDecisionV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AmendmentDecisionV1
Sourceimpl JsonSchema for AmendmentDecisionV1
impl JsonSchema for AmendmentDecisionV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AmendmentDecisionV1
impl PartialEq for AmendmentDecisionV1
Sourcefn eq(&self, other: &AmendmentDecisionV1) -> bool
fn eq(&self, other: &AmendmentDecisionV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for AmendmentDecisionV1
impl Serialize for AmendmentDecisionV1
impl StructuralPartialEq for AmendmentDecisionV1