pub struct AmendmentProposalV1 {
pub schema_version: String,
pub amendment_proposal_id: AmendmentProposalId,
pub charter_bundle_id: CharterBundleId,
pub doctrine_snapshot_id: DoctrineSnapshotId,
pub proposal_title: String,
pub migration_obligations: Vec<String>,
pub semantic_diff_id: Option<SemanticDiffId>,
pub expected_archive_action: Option<String>,
pub required_historical_query_modes: Vec<String>,
pub rollback_handle: Option<String>,
pub advisory_only: bool,
}Fields
schema_version: Stringamendment_proposal_id: AmendmentProposalIdcharter_bundle_id: CharterBundleIddoctrine_snapshot_id: DoctrineSnapshotIdproposal_title: Stringmigration_obligations: Vec<String>semantic_diff_id: Option<SemanticDiffId>expected_archive_action: Option<String>required_historical_query_modes: Vec<String>rollback_handle: Option<String>advisory_only: boolTrait Implementations
Sourceimpl Clone for AmendmentProposalV1
impl Clone for AmendmentProposalV1
Sourcefn clone(&self) -> AmendmentProposalV1
fn clone(&self) -> AmendmentProposalV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AmendmentProposalV1
impl Debug for AmendmentProposalV1
Sourceimpl<'de> Deserialize<'de> for AmendmentProposalV1
impl<'de> Deserialize<'de> for AmendmentProposalV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AmendmentProposalV1
Sourceimpl JsonSchema for AmendmentProposalV1
impl JsonSchema for AmendmentProposalV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AmendmentProposalV1
impl PartialEq for AmendmentProposalV1
Sourcefn eq(&self, other: &AmendmentProposalV1) -> bool
fn eq(&self, other: &AmendmentProposalV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for AmendmentProposalV1
impl Serialize for AmendmentProposalV1
impl StructuralPartialEq for AmendmentProposalV1