pub struct ArchiveManifestV1 {
pub schema_version: String,
pub archive_manifest_id: ArchiveManifestId,
pub charter_bundle_id: CharterBundleId,
pub preserved_refs: Vec<String>,
pub replay_guarantee: String,
}Fields
schema_version: Stringarchive_manifest_id: ArchiveManifestIdcharter_bundle_id: CharterBundleIdpreserved_refs: Vec<String>replay_guarantee: StringTrait Implementations
Sourceimpl Clone for ArchiveManifestV1
impl Clone for ArchiveManifestV1
Sourcefn clone(&self) -> ArchiveManifestV1
fn clone(&self) -> ArchiveManifestV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ArchiveManifestV1
impl Debug for ArchiveManifestV1
Sourceimpl<'de> Deserialize<'de> for ArchiveManifestV1
impl<'de> Deserialize<'de> for ArchiveManifestV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ArchiveManifestV1
Sourceimpl JsonSchema for ArchiveManifestV1
impl JsonSchema for ArchiveManifestV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ArchiveManifestV1
impl PartialEq for ArchiveManifestV1
Sourcefn eq(&self, other: &ArchiveManifestV1) -> bool
fn eq(&self, other: &ArchiveManifestV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ArchiveManifestV1
impl Serialize for ArchiveManifestV1
impl StructuralPartialEq for ArchiveManifestV1