pub struct CharterBundleV1 {
pub schema_version: String,
pub charter_bundle_id: CharterBundleId,
pub charter_name: String,
pub canonical_owner: String,
pub publication_status: SurfaceStatus,
}Fields
schema_version: Stringcharter_bundle_id: CharterBundleIdcharter_name: Stringcanonical_owner: Stringpublication_status: SurfaceStatusTrait Implementations
Sourceimpl Clone for CharterBundleV1
impl Clone for CharterBundleV1
Sourcefn clone(&self) -> CharterBundleV1
fn clone(&self) -> CharterBundleV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CharterBundleV1
impl Debug for CharterBundleV1
Sourceimpl<'de> Deserialize<'de> for CharterBundleV1
impl<'de> Deserialize<'de> for CharterBundleV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CharterBundleV1
Sourceimpl JsonSchema for CharterBundleV1
impl JsonSchema for CharterBundleV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CharterBundleV1
impl PartialEq for CharterBundleV1
Sourcefn eq(&self, other: &CharterBundleV1) -> bool
fn eq(&self, other: &CharterBundleV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CharterBundleV1
impl Serialize for CharterBundleV1
impl StructuralPartialEq for CharterBundleV1