pub struct CompactionReceiptV1 {
pub schema_version: String,
pub compaction_receipt_id: CompactionReceiptId,
pub archive_manifest_id: ArchiveManifestId,
pub dropped_detail_refs: Vec<String>,
pub queryable_degradation_note: String,
}Fields
schema_version: Stringcompaction_receipt_id: CompactionReceiptIdarchive_manifest_id: ArchiveManifestIddropped_detail_refs: Vec<String>queryable_degradation_note: StringTrait Implementations
Sourceimpl Clone for CompactionReceiptV1
impl Clone for CompactionReceiptV1
Sourcefn clone(&self) -> CompactionReceiptV1
fn clone(&self) -> CompactionReceiptV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CompactionReceiptV1
impl Debug for CompactionReceiptV1
Sourceimpl<'de> Deserialize<'de> for CompactionReceiptV1
impl<'de> Deserialize<'de> for CompactionReceiptV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CompactionReceiptV1
Sourceimpl JsonSchema for CompactionReceiptV1
impl JsonSchema for CompactionReceiptV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CompactionReceiptV1
impl PartialEq for CompactionReceiptV1
Sourcefn eq(&self, other: &CompactionReceiptV1) -> bool
fn eq(&self, other: &CompactionReceiptV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CompactionReceiptV1
impl Serialize for CompactionReceiptV1
impl StructuralPartialEq for CompactionReceiptV1