pub struct DeprecationBundleV1 {
pub schema_version: String,
pub deprecation_bundle_id: DeprecationBundleId,
pub charter_bundle_id: CharterBundleId,
pub target_surface: String,
pub replacement_surface: String,
pub advisory_only: bool,
}Fields
schema_version: Stringdeprecation_bundle_id: DeprecationBundleIdcharter_bundle_id: CharterBundleIdtarget_surface: Stringreplacement_surface: Stringadvisory_only: boolTrait Implementations
Sourceimpl Clone for DeprecationBundleV1
impl Clone for DeprecationBundleV1
Sourcefn clone(&self) -> DeprecationBundleV1
fn clone(&self) -> DeprecationBundleV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeprecationBundleV1
impl Debug for DeprecationBundleV1
Sourceimpl<'de> Deserialize<'de> for DeprecationBundleV1
impl<'de> Deserialize<'de> for DeprecationBundleV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DeprecationBundleV1
Sourceimpl JsonSchema for DeprecationBundleV1
impl JsonSchema for DeprecationBundleV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DeprecationBundleV1
impl PartialEq for DeprecationBundleV1
Sourcefn eq(&self, other: &DeprecationBundleV1) -> bool
fn eq(&self, other: &DeprecationBundleV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for DeprecationBundleV1
impl Serialize for DeprecationBundleV1
impl StructuralPartialEq for DeprecationBundleV1