pub struct HistoricalQueryGuaranteeV1 {
pub schema_version: String,
pub historical_query_guarantee_id: HistoricalQueryGuaranteeId,
pub archive_manifest_id: ArchiveManifestId,
pub guarantee_text: String,
pub horizon_only: bool,
pub guaranteed_query_modes: Vec<String>,
}Fields
schema_version: Stringhistorical_query_guarantee_id: HistoricalQueryGuaranteeIdarchive_manifest_id: ArchiveManifestIdguarantee_text: Stringhorizon_only: boolguaranteed_query_modes: Vec<String>Trait Implementations
Sourceimpl Clone for HistoricalQueryGuaranteeV1
impl Clone for HistoricalQueryGuaranteeV1
Sourcefn clone(&self) -> HistoricalQueryGuaranteeV1
fn clone(&self) -> HistoricalQueryGuaranteeV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HistoricalQueryGuaranteeV1
impl Debug for HistoricalQueryGuaranteeV1
Sourceimpl<'de> Deserialize<'de> for HistoricalQueryGuaranteeV1
impl<'de> Deserialize<'de> for HistoricalQueryGuaranteeV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for HistoricalQueryGuaranteeV1
Sourceimpl JsonSchema for HistoricalQueryGuaranteeV1
impl JsonSchema for HistoricalQueryGuaranteeV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for HistoricalQueryGuaranteeV1
impl PartialEq for HistoricalQueryGuaranteeV1
Sourcefn eq(&self, other: &HistoricalQueryGuaranteeV1) -> bool
fn eq(&self, other: &HistoricalQueryGuaranteeV1) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for HistoricalQueryGuaranteeV1