pub struct RetirementBundleV1 {
pub schema_version: String,
pub retirement_bundle_id: RetirementBundleId,
pub deprecation_bundle_id: DeprecationBundleId,
pub horizon_only: bool,
}Fields
schema_version: Stringretirement_bundle_id: RetirementBundleIddeprecation_bundle_id: DeprecationBundleIdhorizon_only: boolTrait Implementations
Sourceimpl Clone for RetirementBundleV1
impl Clone for RetirementBundleV1
Sourcefn clone(&self) -> RetirementBundleV1
fn clone(&self) -> RetirementBundleV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RetirementBundleV1
impl Debug for RetirementBundleV1
Sourceimpl<'de> Deserialize<'de> for RetirementBundleV1
impl<'de> Deserialize<'de> for RetirementBundleV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RetirementBundleV1
Sourceimpl JsonSchema for RetirementBundleV1
impl JsonSchema for RetirementBundleV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RetirementBundleV1
impl PartialEq for RetirementBundleV1
Sourcefn eq(&self, other: &RetirementBundleV1) -> bool
fn eq(&self, other: &RetirementBundleV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RetirementBundleV1
impl Serialize for RetirementBundleV1
impl StructuralPartialEq for RetirementBundleV1